==> chaosmesh-model-6.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface BlockChaosSpecFluent<A extends BlockChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  public A addToContainerNames(Integer index,String item);
  public A setToContainerNames(Integer index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(Integer index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  
  /**
   * This method has been deprecated, please use method buildDelay instead.
   * @return The buildable object.
   */
  @Deprecated
  public BlockDelaySpec getDelay();
  public BlockDelaySpec buildDelay();
  public A withDelay(BlockDelaySpec delay);
  public Boolean hasDelay();
  public A withNewDelay(String correlation,String jitter,String latency);
  public BlockChaosSpecFluent.DelayNested<A> withNewDelay();
  public BlockChaosSpecFluent.DelayNested<A> withNewDelayLike(BlockDelaySpec item);
  public BlockChaosSpecFluent.DelayNested<A> editDelay();
  public BlockChaosSpecFluent.DelayNested<A> editOrNewDelay();
  public BlockChaosSpecFluent.DelayNested<A> editOrNewDelayLike(BlockDelaySpec item);
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public Integer getIops();
  public A withIops(Integer iops);
  public Boolean hasIops();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public BlockChaosSpecFluent.SelectorNested<A> withNewSelector();
  public BlockChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public BlockChaosSpecFluent.SelectorNested<A> editSelector();
  public BlockChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public BlockChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public String getVolumeName();
  public A withVolumeName(String volumeName);
  public Boolean hasVolumeName();
  public interface DelayNested<N> extends Nested<N>,BlockDelaySpecFluent<BlockChaosSpecFluent.DelayNested<N>>{
    public N and();
    public N endDelay();
    
  }
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<BlockChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface BlockChaosSpecFluent<A extends BlockChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  public A addToContainerNames(int index,String item);
  public A setToContainerNames(int index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(int index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  
  /**
   * This method has been deprecated, please use method buildDelay instead.
   * @return The buildable object.
   */
  @Deprecated
  public BlockDelaySpec getDelay();
  public BlockDelaySpec buildDelay();
  public A withDelay(BlockDelaySpec delay);
  public Boolean hasDelay();
  public A withNewDelay(String correlation,String jitter,String latency);
  public BlockChaosSpecFluent.DelayNested<A> withNewDelay();
  public BlockChaosSpecFluent.DelayNested<A> withNewDelayLike(BlockDelaySpec item);
  public BlockChaosSpecFluent.DelayNested<A> editDelay();
  public BlockChaosSpecFluent.DelayNested<A> editOrNewDelay();
  public BlockChaosSpecFluent.DelayNested<A> editOrNewDelayLike(BlockDelaySpec item);
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public Integer getIops();
  public A withIops(Integer iops);
  public Boolean hasIops();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public BlockChaosSpecFluent.SelectorNested<A> withNewSelector();
  public BlockChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public BlockChaosSpecFluent.SelectorNested<A> editSelector();
  public BlockChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public BlockChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public String getVolumeName();
  public A withVolumeName(String volumeName);
  public Boolean hasVolumeName();
  public interface DelayNested<N> extends Nested<N>,BlockDelaySpecFluent<BlockChaosSpecFluent.DelayNested<N>>{
    public N and();
    public N endDelay();
    
  }
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<BlockChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
